/*============================================================================*/
/* POST-APARTHEID INCOME AND EXPENDITURE SERIES                               */
/*----------------------------------------------------------------------------*/
/* Development Policy Research Unit, University of Cape Town. 2016            */ 
/*============================================================================*/
/* File:    01 IES Alignment Master                                           */
/* Purpose: If run from start to finish, this file will compile and align the */
/*          four IESs, creating the PIES dataset.                             */
/*============================================================================*/

quietly {

version 13.1
clear
set more off

*net install st0196.pkg

/*----------------------------------------------------------------------------*/
/* Global macros                                                              */
/*----------------------------------------------------------------------------*/

global PROJECTDIR "$LOCALPATH/PIES Release/"
global DOFILEDIR "$PROJECTDIR/Do Files/"
global DATADIR "$PROJECTDIR/Data/"
global ORIGDATADIR "$PROJECTDIR/Data/IES Data/"

cd "$PROJECTDIR"

/*----------------------------------------------------------------------------*/
/* IES 1995                                                                   */
/*----------------------------------------------------------------------------*/

noisily di _newline(2) "Income and Expenditure Survey 1995:"
noisily di _col(5) "Getting filenames"
do "$DOFILEDIR/01 Filenames 1995.do"
noisily di _col(5) "Merging datasets"
do "$DOFILEDIR/11 Merging 1995.do"
noisily di _col(5) "Merging cross-entropy weights"
do "$DOFILEDIR/21 Weights 1995.do"
noisily di _col(5) "Aligning categories"
do "$DOFILEDIR/31 Align 1995.do"


/*----------------------------------------------------------------------------*/
/* IES 2000                                                                   */
/*----------------------------------------------------------------------------*/

noisily di _newline(4) "Income and Expenditure Survey 2000:"
noisily di _col(5) "Getting filenames"
do "$DOFILEDIR/02 Filenames 2000.do"
noisily di _col(5) "Merging datasets"
do "$DOFILEDIR/12 Merging 2000.do"
noisily di _col(5) "Merging cross-entropy weights"
do "$DOFILEDIR/22 Weights 2000.do"
noisily di _col(5) "Aligning categories"
do "$DOFILEDIR/32 Align 2000.do"

/*----------------------------------------------------------------------------*/
/* IES 2005/06                                                                */
/*----------------------------------------------------------------------------*/

noisily di _newline(4) "Income and Expenditure Survey 2005/2006:"
noisily di _col(5) "Getting filenames"
do "$DOFILEDIR/03 Filenames 2005.do"
noisily di _col(5) "Merging datasets"
do "$DOFILEDIR/13 Merging 2005.do"
noisily di _col(5) "Merging cross-entropy weights"
do "$DOFILEDIR/23 Weights 2005.do"
noisily di _col(5) "Aligning categories"
do "$DOFILEDIR/33 Align 2005.do"

/*----------------------------------------------------------------------------*/
/* IES 2010/11                                                                */
/*----------------------------------------------------------------------------*/

noisily di _newline(4) "Income and Expenditure Survey 2010/2011:"
noisily di _col(5) "Getting filenames"
do "$DOFILEDIR/04 Filenames 2010.do"
noisily di _col(5) "Merging datasets"
do "$DOFILEDIR/14 Merging 2010.do"
noisily di _col(5) "Merging cross-entropy weights"
do "$DOFILEDIR/24 Weights 2010.do"
noisily di _col(5) "Aligning categories"
do "$DOFILEDIR/34 Align 2010.do"			

/*----------------------------------------------------------------------------*/
/* Compiling Data                                                             */
/*----------------------------------------------------------------------------*/

noisily di _newline(4) "Compiling the datasets..."
do "$DOFILEDIR/40 Compiling.do"

}
