/*============================================================================*/
/* POST-APARTHEID INCOME AND EXPENDITURE SERIES                               */
/*----------------------------------------------------------------------------*/
/* Development Policy Research Unit, University of Cape Town. 2015            */ 
/*============================================================================*/
/* File:    11 Merging 1995                                                   */
/* Purpose: This file begins to put together the IES data, creating standard  */
/*          location and household size variables, for example.               */
/*============================================================================*/

use hhid b01* b02* b03* using "$ORIGDATADIR/$FULL1995", clear
rename hhid uqnr
sort uqnr
drop if uqnr==uqnr[_n-1]

rename b01* sex*
rename b02* age*
rename b03* race*

rename *f00* *_*
rename *f0* *_*

reshape long sex_ age_ race_, i(uqnr) j(personnr)
rename *_ *_ies

recode sex (0=.)
recode race (0=.)
replace age = . if age==0 & sex==. & race==.
drop if sex==. & race==. & age==.

tempfile tempiesdata
save `tempiesdata', replace


use uqnr personnr age gender popgroup wave *weight* using "$ORIGDATADIR/$PALMS1995" if wave==2, clear
drop wave bracketweight
rename age age_palms
rename gender sex_palms
rename popgroup race_palms
rename *weight* *weight*_palms
destring uqnr, replace
format uqnr %18.0f
tempfile temppalmsdata
save `temppalmsdata', replace


use "$ORIGDATADIR/$FULL1995", clear
rename hhid uqnr
sort uqnr
drop if uqnr==uqnr[_n-1]

* NOTE: Household member information in the IES 1995 was limited by StatsSA to 
*       10 members only. This was not the case in the accompanying OHS 1995.

gen ieshhgender = b01f001 
gen ieshhage = b02f001
gen ieshhrace = b03f001 

foreach var of varlist b01f* b02f* b03f* {
	recode `var' (0=.)
}

egen ieshhsize_sex = rownonmiss(b01f*)
egen ieshhsize_age = rownonmiss(b02f*)
egen ieshhsize_race = rownonmiss(b03f*)

foreach var of varlist ieshhsize_* {
	replace `var'=. if `var'==0
}

recode c6 (11/24=1) (else=0), gen(urban)
* NOTE: Codes for area types can be found in the OHS 1995 metadata
la var urban "Urban dummy (urban=1)"

gen province = int(c1/100)
la var province "Province"

gen agegrp = min(17,int(ieshhage/5))

drop b01f* b02f* b03f* b04f* b05f* c3 c4 c5 c6

merge 1:m uqnr using `tempiesdata', nogen
merge 1:1 uqnr personnr using `temppalmsdata'
drop if _merge==2
drop _merge

order uqnr personnr ieshhgender ieshhage ieshhrace ieshhsize_sex ieshhsize_age ieshhsize_race agegrp sex_ies age_ies race_ies sex_palms age_palms race_palms ceweight_palms ceweight2_palms pweight_palms hweight_palms weight urban province

la var sex_palms "Sex (1=Male 2=Female), from PALMS"
la var age_palms "Age, from PALMS"
la var race_palms "Race, from PALMS"

la var sex_ies "Sex (1=Male 2=Female), from IES"
la var age_ies "Age, from IES"
la var race_ies "Race, from IES"

rename c1 district
la var district "District (c1 variable)"
rename c2 ea
la var ea "Enumerator area (c2 variable)"

save "$DATADIR/IES1995_Merged.dta", replace



