/*============================================================================*/
/* POST-APARTHEID INCOME AND EXPENDITURE SERIES                               */
/*----------------------------------------------------------------------------*/
/* Development Policy Research Unit, University of Cape Town. 2015            */ 
/*============================================================================*/
/* File:    13 Merging 2005                                                   */
/* Purpose: This file begins to put together the IES data, creating standard  */
/*          location and household size variables, for example.               */
/*============================================================================*/

import excel "$ORIGDATADIR/IES200506_Age.xlsx", sheet("Sheet1") firstrow clear
rename *no *nr
rename AGE age
order uqnr personnr age
destring uqnr, replace
format uqnr %14.0f
destring personnr, replace

tempfile IES2005_Age
save `IES2005_Age'

/*----------------------------------------------------------------------------*/

use "$ORIGDATADIR/$PERSINCOME2005", clear
di "$ORIGDATADIR/$PERSINCOME2005"
rename *no *nr
rename value* inc*
keep uqnr personnr coicop inc
reshape wide inc, i(uqnr personnr) j(coicop)
recode inc* (.=0)

tempfile IES2005_Inc
save `IES2005_Inc'

/*----------------------------------------------------------------------------*/

use "$ORIGDATADIR/$ITEMS2005", clear

noisily di "This may take a while. Please be patient"
rename uqno uqnr
keep uqnr coicop valueannualized weight
rename valueannualized exp 
collapse (sum) exp, by(uqnr coicop)
reshape wide exp, i(uqnr) j(coicop)
recode exp* (.=0)
order uqnr

tempfile IES2005_Exp
save `IES2005_Exp'

/*----------------------------------------------------------------------------*/

use "$ORIGDATADIR/$HOUSEHOLD2005", clear

rename *, lower
rename hsize hhsize
rename uqno uqnr
recode settlement (1=1) (2=0), gen(urban)
drop settlement weight popgrpofhead genderofhead surveyyear surveymonth q16support q17numsupport q31dwelltypemain q31dwelltypeoth q32materialwalls q32materialroof q33govgrant q35typetoilet q36sharetoilet q37streetlight q38elecsupply q39energycook q39energyheat q39energylight q310refuse radio stereo_hifi tape_recorder television video_cassette_recorder_dvd refrigerator_freezer stove__gas_or_electric microwave washing_machine motor_vehicle motor_cycle_scooter sewing_knitting_machine donkey_cart_ox_cart plough tractor wheelbarrow grinding_mill bicycle computer canoeboat motorboat camera bed cell_telephone landline_telephone satellite_dish internet_service q41aoccrooms q41anorooms q41boccrooms q41bnorooms q41coccrooms q41cnorooms q41doccrooms q41dnorooms q41eoccrooms q41enorooms q41foccrooms q41fnorooms q42garage q42nocars q44value q44valueimputed q45ownrent q41totoccrooms q41totnorooms

tempfile IES2005_Prov
save `IES2005_Prov'

/*----------------------------------------------------------------------------*/


use "$ORIGDATADIR/$PERSON2005", clear

rename *, lower
rename uqno uqnr
rename personno personnr
rename popgrp race
rename gender sex

sort uqnr personnr

rename q15higheduc education

merge 1:1 uqnr personnr using `IES2005_Age'
assert _merge==3
drop _merge

sort uqnr personnr
keep uqnr personnr race age education weight sex

merge 1:m uqnr personnr using `IES2005_Inc'
drop _merge

merge m:1 uqnr using `IES2005_Prov'
drop _merge
	
merge m:1 uqnr using `IES2005_Exp'
drop _merge

save "$DATADIR/IES2005_Merged.dta", replace
