/*============================================================================*/
/* POST-APARTHEID INCOME AND EXPENDITURE SERIES                               */
/*----------------------------------------------------------------------------*/
/* Development Policy Research Unit, University of Cape Town. 2015            */ 
/*============================================================================*/
/* File:    14 Compile 2010                                                   */
/* Purpose: This file begins to put together the IES data, creating standard  */
/*          location and household size variables, for example.               */
/*============================================================================*/

use "$ORIGDATADIR/$HOUSEHOLD2010", clear
rename *, lower
rename uqno uqnr
rename hsize hhsize

recode settlement_type (1/2=1) (4/5=0), gen(urban)

keep uqnr province hhsize consumptions inkindconsumptions income inkindincome urban
tempfile IES2010_Prov
save `IES2010_Prov', replace

/*----------------------------------------------------------------------------*/

use "$ORIGDATADIR/$PERSINCOME2010", clear
rename *, lower
rename *no *nr

keep uqnr personnr coicop value
reshape wide value, i(uqnr personnr) j(coicop)
rename value* inc*
recode inc* (.=0)

tempfile IES2010_Inc
save `IES2010_Inc'

/*----------------------------------------------------------------------------*/

noisily di "This may take a while. Please be patient"
use "$ORIGDATADIR/$ITEMS2010", clear
rename *, lower
rename uqno uqnr
drop coicoptype aop tor valuemain valuediary value valuemainannualized valuediaryannualized province settlement_type *ofhead full_calwgt
rename valueannualized value 
collapse (sum) value, by(uqnr coicop)
rename value exp
reshape wide exp, i(uqnr) j(coicop)

order uqnr

tempfile IES2010_Exp
save `IES2010_Exp'

/*----------------------------------------------------------------------------*/

use "$ORIGDATADIR/$PERSON2010", clear
rename *, lower
rename uqno uqnr
rename personno personnr
keep uqnr personnr province settlement_type q12sex q13popgroup q14age q21highestlevel full_calwgt
rename full_calwgt weight
recode settlement_type (1 2 = 1) (4 5 = 0), gen(urban)
drop settlement_type
rename q12sex sex
rename q13popgroup race
rename q14age age
rename q21highestlevel education

merge m:1 uqnr using `IES2010_Prov'
drop _merge

merge m:1 uqnr using `IES2010_Exp'
drop _merge

merge 1:1 uqnr personnr using `IES2010_Inc'
drop _merge

save "$DATADIR/IES2010_Merged.dta", replace
