/*============================================================================*/
/* POST-APARTHEID INCOME AND EXPENDITURE SERIES                               */
/*----------------------------------------------------------------------------*/
/* Development Policy Research Unit, University of Cape Town. 2015            */ 
/*============================================================================*/
/* File:    31 Align 1995                                                     */
/* Purpose: This file aligns the IES 1995 categories.                         */
/*============================================================================*/

/*----------------------------------------------------------------------------*/
/* INCOME - HOUSEHOLD AND INDIVIDUAL                                          */
/*----------------------------------------------------------------------------*/

import excel "$PROJECTDIR/IES Income Matching.xlsx", sheet("Final") firstrow case(lower) clear
keep code1995
drop if code1995==""

outfile code1995 using "$DOFILEDIR/31-01 Household Income Alignment Code 1995.do", replace noquote


/*----------------------------------------------------------------------------*/
/* EXPENDITURE - HOUSEHOLD                                                    */
/*----------------------------------------------------------------------------*/

import excel "$PROJECTDIR/IES Expenditure Matching.xlsx", sheet("Expenditure") firstrow case(lower) clear
keep code1995
drop if code1995==""

outfile code1995 using "$DOFILEDIR/31-02 Expenditure Alignment Code 1995.do", replace noquote


/*----------------------------------------------------------------------------*/
/* DEBTS - HOUSEHOLD                                                          */
/*----------------------------------------------------------------------------*/

import excel "$PROJECTDIR/IES Expenditure Matching.xlsx", sheet("Other") firstrow case(lower) clear
keep code1995
drop if code1995==""

outfile code1995 using "$DOFILEDIR/31-03 Debt Alignment Code 1995.do", replace noquote


/*----------------------------------------------------------------------------*/
/* INCOMPLETE MATCHES - HOUSEHOLD                                             */
/*----------------------------------------------------------------------------*/

import excel "$PROJECTDIR/IES Expenditure Matching.xlsx", sheet("Incomplete Matches") firstrow case(lower) clear
keep code1995
drop if code1995==""

outfile code1995 using "$DOFILEDIR/31-04 Incomplete Matches Code 1995.do", replace noquote


/*----------------------------------------------------------------------------*/
/* COMPILING DATA                                                             */
/*----------------------------------------------------------------------------*/

use "$DATADIR/IES1995_Compiled.dta", clear
sort uqnr personnr

forvalues counter = 83(1)87 {
	lookfor b`counter'f0 b`counter'f1
	tokenize `r(varlist)'
	
	while "`1'"~="" {
		replace `1' = `1'*(personnr==b`counter'f200)
		macro shift
	}
}	
	

drop b72f001-b80f100	/* Details of own production and consumption thereof */
drop b81f*				/* Input costs (for own production) */
drop b89*				/* Totals at the end of the questionnaire */

gen zero = 0

noisily di "Aligning 1995 Income"
do "$DOFILEDIR/31-01 Household Income Alignment Code 1995.do"

noisily di "Aligning 1995 Expenditure"
do "$DOFILEDIR/31-02 Expenditure Alignment Code 1995.do"

	gen TOTAL_EXP_excl = Food + Nonalcoholic + Alcohol + Tobacco + Clothing + Fuel + Furnequip + Hhmaint + Communication + Computer + Transport + Reading + Housing + Restaurant + Health + Recreation + Education + Personalcare + Personaleffects + Feesandgifts + Finance + Otherexp
	la var TOTAL_EXP_excl "Total expenditure, excluding unmatched expenditures"
	gen TOTAL_EXP_incl = TOTAL_EXP_excl + Unmatchedexp
	la var TOTAL_EXP_incl "Total expenditure, including unmatched expenditures"

noisily di "Aligning 1995 Debt"
do "$DOFILEDIR/31-03 Debt Alignment Code 1995.do"

noisily di "Aligning 1995 Incomplete Matches"
do "$DOFILEDIR/31-04 Incomplete Matches Code 1995.do"

sort uqnr personnr
notes drop _dta

/* ALIGNED PERSONAL INCOME FILE */
preserve
	keep uqnr personnr p_wages_inc p_oap_inc p_dg_inc p_othgrants_inc p_Work_inc p_Grants_inc 
	save "$DATADIR/IES1995_PersonIncome.dta", replace
restore

/* ALIGNED HOUSEHOLD INCOME FILE */
preserve
	drop if uqnr==uqnr[_n-1]
	keep uqnr wages_inc oap_inc dg_inc othgrants_inc Work_inc Grants_inc Allother_inc TOTAL_INC
	save "$DATADIR/IES1995_HouseholdIncome.dta", replace
restore

/* ALIGNED HOUSEHOLD EXPENDITURE FILE */
preserve
	drop if uqnr==uqnr[_n-1]
	keep uqnr cakeflour_gr-TOTAL_EXP_incl
	save "$DATADIR/IES1995_Expenditure.dta", replace
restore

/* ALIGNED HOUSEHOLD DEBTS FILE */
preserve
	drop if uqnr==uqnr[_n-1]
	keep uqnr *_de Debts _unmatcheddebts
	save "$DATADIR/IES1995_Debt.dta", replace
restore

/* REMAINING UNALIGNED VARIABLES - HOUSEHOLD FILE */
preserve
	drop if uqnr==uqnr[_n-1]
	keep uqnr _dissaving_in _imputedrent_in _imputedrent_out _imputedrent7_out
	save "$DATADIR/IES1995_HouseholdUnaligned.dta", replace
restore



drop p_wages_inc p_oap_inc p_dg_inc p_othgrants_inc p_Work_inc p_Grants_inc 
drop wages_inc oap_inc dg_inc othgrants_inc Work_inc Grants_inc Allother_inc TOTAL_INC
drop cakeflour_gr-TOTAL_EXP_incl
drop *_de Debts
drop _dissaving_in _imputedrent_in _imputedrent_out _imputedrent7_out
capture drop zero
drop *_inc

