/*============================================================================*/
/* POST-APARTHEID INCOME AND EXPENDITURE SERIES                               */
/*----------------------------------------------------------------------------*/
/* Development Policy Research Unit, University of Cape Town. 2015            */ 
/*============================================================================*/
/* File:    32 Align 2000                                                     */
/* Purpose: This file aligns the IES 2000 categories.                         */
/*============================================================================*/


/*----------------------------------------------------------------------------*/
/* INCOME - HOUSEHOLD AND INDIVIDUAL                                          */
/*----------------------------------------------------------------------------*/

import excel "$PROJECTDIR/IES Income Matching.xlsx", sheet("Final") firstrow case(lower) clear
keep code2000
drop if code2000==""

outfile code2000 using "$DOFILEDIR/32-01 Household Income Alignment Code 2000.do", replace noquote


/*----------------------------------------------------------------------------*/
/* EXPENDITURE - HOUSEHOLD                                                    */
/*----------------------------------------------------------------------------*/

import excel "$PROJECTDIR/IES Expenditure Matching.xlsx", sheet("Expenditure") firstrow case(lower) clear
keep code2000
drop if code2000==""

outfile code2000 using "$DOFILEDIR/32-02 Expenditure Alignment Code 2000.do", replace noquote


/*----------------------------------------------------------------------------*/
/* DEBTS - HOUSEHOLD                                                          */
/*----------------------------------------------------------------------------*/

import excel "$PROJECTDIR/IES Expenditure Matching.xlsx", sheet("Other") firstrow case(lower) clear
keep code2000
drop if code2000==""

outfile code2000 using "$DOFILEDIR/32-03 Debt Alignment Code 2000.do", replace noquote


/*----------------------------------------------------------------------------*/
/* INCOMPLETE MATCHES - HOUSEHOLD                                             */
/*----------------------------------------------------------------------------*/

import excel "$PROJECTDIR/IES Expenditure Matching.xlsx", sheet("Incomplete Matches") firstrow case(lower) clear
keep code2000
drop if code2000==""

outfile code2000 using "$DOFILEDIR/32-04 Incomplete Matches Code 2000.do", replace noquote


/*----------------------------------------------------------------------------*/
/* COMPILING DATA                                                             */
/*----------------------------------------------------------------------------*/

use "$DATADIR/IES2000_Compiled.dta", clear
sort uqnr personnr
gen zero = 0
noisily di "Aligning 2000 Income"
do "$DOFILEDIR/32-01 Household Income Alignment Code 2000.do"

noisily di "Aligning 2000 Expenditure"
do "$DOFILEDIR/32-02 Expenditure Alignment Code 2000.do"

	gen TOTAL_EXP_excl = Food + Nonalcoholic + Alcohol + Tobacco + Clothing + Fuel + Furnequip + Hhmaint + Communication + Computer + Transport + Reading + Housing + Restaurant + Health + Recreation + Education + Personalcare + Personaleffects + Feesandgifts + Finance + Otherexp
	la var TOTAL_EXP_excl "Total expenditure, excluding unmatched expenditures"
	gen TOTAL_EXP_incl = TOTAL_EXP_excl + Unmatchedexp
	la var TOTAL_EXP_incl "Total expenditure, including unmatched expenditures"

noisily di "Aligning 2000 Debt"
do "$DOFILEDIR/32-03 Debt Alignment Code 2000.do"

noisily di "Aligning 2000 Incomplete Matches"
gen _imputedrent_out = .
gen _imputedrent7_out = .
do "$DOFILEDIR/32-04 Incomplete Matches Code 2000.do"

notes drop _dta

/* ALIGNED PERSONAL INCOME FILE */
preserve
	keep uqnr personnr p_wages_inc p_oap_inc p_dg_inc p_othgrants_inc p_Work_inc p_Grants_inc 
	save "$DATADIR/IES2000_PersonIncome.dta", replace
restore

/* ALIGNED HOUSEHOLD INCOME FILE */
preserve
	drop if uqnr==uqnr[_n-1]
	keep uqnr wages_inc oap_inc dg_inc othgrants_inc Work_inc Grants_inc Allother_inc TOTAL_INC
	save "$DATADIR/IES2000_HouseholdIncome.dta", replace
restore

/* ALIGNED HOUSEHOLD EXPENDITURE FILE */
preserve
	drop if uqnr==uqnr[_n-1]
	keep uqnr cakeflour_gr-TOTAL_EXP_incl
	save "$DATADIR/IES2000_Expenditure.dta", replace
restore

/* ALIGNED HOUSEHOLD DEBTS FILE */
preserve
	drop if uqnr==uqnr[_n-1]
	keep uqnr *_de Debts _unmatcheddebts
	save "$DATADIR/IES2000_Debt.dta", replace
restore

/* REMAINING UNALIGNED VARIABLES - HOUSEHOLD FILE */
preserve
	drop if uqnr==uqnr[_n-1]
	keep uqnr _dissaving_in _imputedrent_in _imputedrent_out _imputedrent7_out
	save "$DATADIR/IES2000_HouseholdUnaligned.dta", replace
restore

drop p_wages_inc p_oap_inc p_dg_inc p_othgrants_inc p_Work_inc p_Grants_inc 
drop wages_inc oap_inc dg_inc othgrants_inc Work_inc Grants_inc Allother_inc TOTAL_INC
drop cakeflour_gr-TOTAL_EXP_incl
drop *_de Debts
drop _dissaving_in _imputedrent_in _imputedrent_out _imputedrent7_out
capture drop zero
drop *_inc

