/*============================================================================*/
/* POST-APARTHEID INCOME AND EXPENDITURE SERIES                               */
/*----------------------------------------------------------------------------*/
/* Development Policy Research Unit, University of Cape Town. 2015            */ 
/*============================================================================*/
/* File:    33 IES 2005 Alignment                                             */
/* Purpose: This file aligns the IES 2005 categories.                         */
/*============================================================================*/


/*----------------------------------------------------------------------------*/
/* INCOME - HOUSEHOLD AND INDIVIDUAL                                          */
/*----------------------------------------------------------------------------*/

import excel "$PROJECTDIR/IES Income Matching.xlsx", sheet("Final") firstrow case(lower) clear
keep code2005
drop if code2005==""

outfile code2005 using "$DOFILEDIR/33-01 Household Income Alignment Code 2005.do", replace noquote


/*----------------------------------------------------------------------------*/
/* EXPENDITURE - HOUSEHOLD                                                    */
/*----------------------------------------------------------------------------*/

import excel "$PROJECTDIR/IES Expenditure Matching.xlsx", sheet("Expenditure") firstrow case(lower) clear
keep code2005
drop if code2005==""

outfile code2005 using "$DOFILEDIR/33-02 Expenditure Alignment Code 2005.do", replace noquote


/*----------------------------------------------------------------------------*/
/* DEBTS - HOUSEHOLD                                                          */
/*----------------------------------------------------------------------------*/

import excel "$PROJECTDIR/IES Expenditure Matching.xlsx", sheet("Other") firstrow case(lower) clear
keep code2005
drop if code2005==""

outfile code2005 using "$DOFILEDIR/33-03 Debt Alignment Code 2005.do", replace noquote


/*----------------------------------------------------------------------------*/
/* INCOMPLETE MATCHES - HOUSEHOLD                                             */
/*----------------------------------------------------------------------------*/

import excel "$PROJECTDIR/IES Expenditure Matching.xlsx", sheet("Incomplete Matches") firstrow case(lower) clear
keep code2005
drop if code2005==""

outfile code2005 using "$DOFILEDIR/33-04 Incomplete Matches Code 2005.do", replace noquote


/*----------------------------------------------------------------------------*/
/* COMPILING DATA                                                             */
/*----------------------------------------------------------------------------*/

use "$DATADIR/IES2005_Compiled.dta", clear
sort uqnr personnr
gen zero = 0
noisily di "Aligning 2005 Income"
do "$DOFILEDIR/33-01 Household Income Alignment Code 2005.do"

noisily di "Aligning 2005 Expenditure"
do "$DOFILEDIR/33-02 Expenditure Alignment Code 2005.do"

	gen TOTAL_EXP_excl = Food + Nonalcoholic + Alcohol + Tobacco + Clothing + Fuel + Furnequip + Hhmaint + Communication + Computer + Transport + Reading + Housing + Restaurant + Health + Recreation + Education + Personalcare + Personaleffects + Feesandgifts + Finance + Otherexp
	la var TOTAL_EXP_excl "Total expenditure, excluding unmatched expenditures"
	gen TOTAL_EXP_incl = TOTAL_EXP_excl + Unmatchedexp
	la var TOTAL_EXP_incl "Total expenditure, including unmatched expenditures"

noisily di "Aligning 2005 Debt"
do "$DOFILEDIR/33-03 Debt Alignment Code 2005.do"

noisily di "Aligning 2005 Incomplete Matches"
do "$DOFILEDIR/33-04 Incomplete Matches Code 2005.do"

drop exp66*													/* Input costs */
drop exp51*													/* In-kind incomes */
drop exp4411210 exp4431210 exp4511210 exp4541102 exp4541502	/* In-kind consumptions with no counterparts in 1995/2000 surveys */
drop exp99111302											/* In-kind transfer with no counterparts in 1995/2000 surveys */

notes drop _dta

/* ALIGNED PERSONAL INCOME FILE */
preserve
	keep uqnr personnr p_wages_inc p_oap_inc p_dg_inc p_othgrants_inc p_Work_inc p_Grants_inc 
	save "$DATADIR/IES2005_PersonIncome.dta", replace
restore

/* ALIGNED HOUSEHOLD INCOME FILE */
preserve
	drop if uqnr==uqnr[_n-1]
	keep uqnr wages_inc oap_inc dg_inc othgrants_inc Work_inc Grants_inc Allother_inc TOTAL_INC
	save "$DATADIR/IES2005_HouseholdIncome.dta", replace
restore

/* ALIGNED HOUSEHOLD EXPENDITURE FILE */
preserve
	drop if uqnr==uqnr[_n-1]
	keep uqnr cakeflour_gr-TOTAL_EXP_incl
	save "$DATADIR/IES2005_Expenditure.dta", replace
restore

/* ALIGNED HOUSEHOLD DEBTS FILE */
preserve
	drop if uqnr==uqnr[_n-1]
	keep uqnr *_de Debts _unmatcheddebts
	save "$DATADIR/IES2005_Debt.dta", replace
restore

/* REMAINING UNALIGNED VARIABLES - HOUSEHOLD FILE */
preserve
	drop if uqnr==uqnr[_n-1]
	keep uqnr _dissaving_in _imputedrent_in _imputedrent_out _imputedrent7_out
	save "$DATADIR/IES2005_HouseholdUnaligned.dta", replace
restore

drop p_wages_inc p_oap_inc p_dg_inc p_othgrants_inc p_Work_inc p_Grants_inc 
drop wages_inc oap_inc dg_inc othgrants_inc Work_inc Grants_inc Allother_inc TOTAL_INC
drop cakeflour_gr-TOTAL_EXP_incl
drop *_de Debts _unmatcheddebts
drop _dissaving_in _imputedrent_in _imputedrent_out _imputedrent7_out
capture drop zero
capture drop *_inc


