/*============================================================================*/
/* POST-APARTHEID INCOME AND EXPENDITURE SERIES                               */
/*----------------------------------------------------------------------------*/
/* Development Policy Research Unit, University of Cape Town. 2015            */ 
/*============================================================================*/
/* File:    40 Compiling                                                      */
/* Purpose: This file compiles the Post-Apartheid Income and Expenditure      */
/*          series.                                                           */
/*============================================================================*/

/*----------------------------------------------------------------------------*/
/* 1995 IES Combined File                                                     */
/*----------------------------------------------------------------------------*/

noisily di "Compiling the 1995 data..."

use "$DATADIR/IES1995_Roster.dta", clear
merge m:1 uqnr using "$DATADIR/IES1995_Expenditure.dta"
assert _merge==3
drop _merge

merge m:1 uqnr using "$DATADIR/IES1995_HouseholdIncome.dta"
assert _merge==3
drop _merge

merge 1:1 uqnr personnr using "$DATADIR/IES1995_PersonIncome.dta"
assert _merge==3
drop _merge

merge m:1 uqnr using "$DATADIR/IES1995_Debt.dta"
assert _merge==3
drop _merge

merge m:1 uqnr using "$DATADIR/IES1995_HouseholdUnaligned.dta"
assert _merge==3
drop _merge

capture tostring uqnr, replace format(%18.0f)
compress
notes drop _dta

note: PIES: 1995, nominal values
note: Compiled by Development Policy Research Unit, University of Cape Town
note: PIES Version: 1.0

save "$DATADIR/PIES1995.dta", replace


/*----------------------------------------------------------------------------*/
/* 2000 IES Combined File                                                     */
/*----------------------------------------------------------------------------*/

noisily di "Compiling the 2000 data..."

use "$DATADIR/IES2000_Roster.dta", clear
merge m:1 uqnr using "$DATADIR/IES2000_Expenditure.dta"
assert _merge==3
drop _merge

merge m:1 uqnr using "$DATADIR/IES2000_HouseholdIncome.dta"
assert _merge==3
drop _merge

merge 1:1 uqnr personnr using "$DATADIR/IES2000_PersonIncome.dta"
assert _merge==3
drop _merge

merge m:1 uqnr using "$DATADIR/IES2000_Debt.dta"
assert _merge==3
drop _merge

merge m:1 uqnr using "$DATADIR/IES2000_HouseholdUnaligned.dta"
assert _merge==3
drop _merge

capture tostring uqnr, replace format(%18.0f)
compress
notes drop _dta

note: PIES: 2000, nominal values
note: Compiled by Development Policy Research Unit, University of Cape Town
note: PIES Version: 1.0

save "$DATADIR/PIES2000.dta", replace


/*----------------------------------------------------------------------------*/
/* 2005 IES Combined File                                                     */
/*----------------------------------------------------------------------------*/

noisily di "Compiling the 2005 data..."

use "$DATADIR/IES2005_Roster.dta", clear
merge m:1 uqnr using "$DATADIR/IES2005_Expenditure.dta"
assert _merge==3
drop _merge

merge m:1 uqnr using "$DATADIR/IES2005_HouseholdIncome.dta"
assert _merge==3
drop _merge

merge 1:1 uqnr personnr using "$DATADIR/IES2005_PersonIncome.dta"
assert _merge==3
drop _merge

merge m:1 uqnr using "$DATADIR/IES2005_Debt.dta"
assert _merge==3
drop _merge

merge m:1 uqnr using "$DATADIR/IES2005_HouseholdUnaligned.dta"
assert _merge==3
drop _merge

capture tostring uqnr, replace format(%18.0f)
compress
notes drop _dta

note: PIES: 2005/06, nominal values
note: Compiled by Development Policy Research Unit, University of Cape Town
note: PIES Version: 1.0

save "$DATADIR/PIES2005.dta", replace


/*----------------------------------------------------------------------------*/
/* 2010 IES Combined File                                                     */
/*----------------------------------------------------------------------------*/

noisily di "Compiling the 2010 data..."

use "$DATADIR/IES2010_Roster.dta", clear
merge m:1 uqnr using "$DATADIR/IES2010_Expenditure.dta"
assert _merge==3
drop _merge

merge m:1 uqnr using "$DATADIR/IES2010_HouseholdIncome.dta"
assert _merge==3
drop _merge

merge 1:1 uqnr personnr using "$DATADIR/IES2010_PersonIncome.dta"
assert _merge==3
drop _merge

merge m:1 uqnr using "$DATADIR/IES2010_Debt.dta"
assert _merge==3
drop _merge

merge m:1 uqnr using "$DATADIR/IES2010_HouseholdUnaligned.dta"
assert _merge==3
drop _merge

capture tostring uqnr, replace format(%18.0f)
compress
notes drop _dta

note: PIES: 2010/11, nominal values
note: Compiled by Development Policy Research Unit, University of Cape Town
note: PIES Version: 1.0

save "$DATADIR/PIES2010.dta", replace


/*----------------------------------------------------------------------------*/
/* Combined PIES File                                                         */
/*----------------------------------------------------------------------------*/

noisily di "Compiling the full PIES dataset..."

use "$DATADIR/PIES1995.dta", clear
gen year = 1995

append using "$DATADIR/PIES2000.dta"
replace year = 2000 if year==.

append using "$DATADIR/PIES2005.dta"
replace year = 2005 if year==.

append using "$DATADIR/PIES2010.dta"
replace year = 2010 if year==.

order uqnr personnr year

note drop _dta in 4/l
note replace _dta in 1: PIES: 1995-2010, nominal values

save "$DATADIR/PIES_nominal.dta", replace



/*----------------------------------------------------------------------------*/
/* Real PIES File - Single Deflator                                           */
/*----------------------------------------------------------------------------*/

noisily di "Compiling the constant prices (single deflator) PIES dataset..."

import excel "$DATADIR/CPI/Consumer Price Indices.xlsx", sheet("Linked CPI") firstrow case(lower) clear
drop in 1

local row = 1

foreach category in gr me fi mi fa fr ve su co fn cd al to cl other total {
	forvalues year = 1995(5)2010 {
		su ies`year' if _n==`row'
		local CPI`year'_`category' = `r(mean)'
	}
	local row = `row'+1
}

use "$DATADIR/PIES_nominal.dta", clear

foreach var of varlist cakeflour_gr-_imputedrent7_out {
	forvalues year = 1995(5)2010 {
		replace `var' = (`var')/(`CPI`year'_total') *100 if year==`year'
	}
}

note replace _dta in 1: PIES: 1995-2010, real values (single deflator)

save "$DATADIR/PIES_real1.dta", replace


/*----------------------------------------------------------------------------*/
/* Real PIES File - Multiple Deflators                                        */
/*----------------------------------------------------------------------------*/

noisily di "Compiling the constant prices (multiple deflator) PIES dataset..."

use "$DATADIR/PIES_nominal.dta", clear

foreach category in gr me fi mi fa fr ve su co fn cd al to cl {
	ds *_`category'

	tokenize "`r(varlist)'"
	while "`1'"~="" {
		forvalues year = 1995(5)2010 {
			replace `1' = `1'/`CPI`year'_`category''*100 if year==`year'
		}
		macro shift
	}
	
}

foreach category in fu ff tx ap mu eq hg hs tc ct pv rc pt np ho rh he re ed pc pe fg fc ot xx {
	ds *_`category'
	
	tokenize "`r(varlist)'"
	while "`1'"~="" {
		forvalues year = 1995(5)2010 {
			replace `1' = `1'/`CPI`year'_other'*100 if year==`year'
		}
		macro shift
	}	
}


tempvar temp
egen `temp' = rowtotal(*_gr)
replace Grain_fo = `temp'
drop `temp'

egen `temp' = rowtotal(*_me)
replace Meat_fo = `temp'
drop `temp'

egen `temp' = rowtotal(*_fi)
replace Fish_fo = `temp'
drop `temp'

egen `temp' = rowtotal(*_mi)
replace Milk_fo = `temp'
drop `temp'

egen `temp' = rowtotal(*_fa)
replace Fats_fo = `temp'
drop `temp'

egen `temp' = rowtotal(*_ve)
replace Vegetables_fo = `temp'
drop `temp'

egen `temp' = rowtotal(*_fr)
replace Fruit_fo = `temp'
drop `temp'

egen `temp' = rowtotal(*_su)
replace Sugar_fo = `temp'
drop `temp'

egen `temp' = rowtotal(*_fn)
replace Foodnec_fo = `temp'
drop `temp'

egen `temp' = rowtotal(*_fo)
replace Food = `temp'
drop `temp'

egen `temp' = rowtotal(*_co)
replace Coffee_nb = `temp'
drop `temp'

egen `temp' = rowtotal(*_cd)
replace Colddrink_nb = `temp'
drop `temp'

egen `temp' = rowtotal(*_nb)
replace Nonalcoholic = `temp'
drop `temp'

egen `temp' = rowtotal(*_al)
replace Alcohol = `temp'
drop `temp'

egen `temp' = rowtotal(*_to)
replace Tobacco = `temp'
drop `temp'

egen `temp' = rowtotal(*_cl)
replace Clothing = `temp'
drop `temp'

egen `temp' = rowtotal(*_fu)
replace Fuel = `temp'
drop `temp'

egen `temp' = rowtotal(*_ff)
replace Furniture_fe = `temp'
drop `temp'

egen `temp' = rowtotal(*_tx)
replace Textiles_fe = `temp'
drop `temp'

egen `temp' = rowtotal(*_ap)
replace Appliances_fe = `temp'
drop `temp'

egen `temp' = rowtotal(*_mu)
replace Musical_fe = `temp'
drop `temp'

egen `temp' = rowtotal(*_eq)
replace Equipment_fe = `temp'
drop `temp'

egen `temp' = rowtotal(*_fe)
replace Furnequip = `temp'
drop `temp'

egen `temp' = rowtotal(*_hg)
replace Hhgoods_hm = `temp'
drop `temp'

egen `temp' = rowtotal(*_hs)
replace Hhservices_hm = `temp'
drop `temp'

egen `temp' = rowtotal(*_hm)
replace Hhmaint = `temp'
drop `temp'

egen `temp' = rowtotal(*_tc)
replace Communication = `temp'
drop `temp'

egen `temp' = rowtotal(*_ct)
replace Computer = `temp'
drop `temp'

egen `temp' = rowtotal(*_pv)
replace Vehicles_tr = `temp'
drop `temp'

egen `temp' = rowtotal(*_rc)
replace Runningcosts_tr = `temp'
drop `temp'

egen `temp' = rowtotal(*_pt)
replace Publictransport_tr = `temp'
drop `temp'

egen `temp' = rowtotal(*_tr)
replace Transport = `temp'
drop `temp'

egen `temp' = rowtotal(*_np)
replace Reading = `temp'
drop `temp'

egen `temp' = rowtotal(*_ho)
replace Housing = `temp'
drop `temp'

egen `temp' = rowtotal(*_rh)
replace Restaurant = `temp'
drop `temp'

egen `temp' = rowtotal(*_he)
replace Health = `temp'
drop `temp'

egen `temp' = rowtotal(*_re)
replace Recreation = `temp'
drop `temp'

egen `temp' = rowtotal(*_ed)
replace Education = `temp'
drop `temp'

egen `temp' = rowtotal(*_pc)
replace Personalcare = `temp'
drop `temp'

egen `temp' = rowtotal(*_pe)
replace Personaleffects = `temp'
drop `temp'

egen `temp' = rowtotal(*_fg)
replace Feesandgifts = `temp'
drop `temp'

egen `temp' = rowtotal(*_fc)
replace Finance = `temp'
drop `temp'

egen `temp' = rowtotal(*_ot)
replace Otherexp = `temp'
drop `temp'

egen `temp' = rowtotal(*_xx)
replace Unmatchedexp = `temp'
drop `temp'

local chosen = "A"

while "`chosen'"~="I" & "`chosen'"~="E" {
	noisily di as result "Should the income deflator be calculated " as input "I" as result "ncluding or " as input "E" as result "xcluding unmatched expenditures? (I/E)", _request(_chosen)
	local chosen = upper("`chosen'")
}

noisily di "`chosen'"

if "`chosen'"=="E" {
	gen `temp' = Food + Nonalcoholic + Alcohol + Tobacco + Clothing + Fuel + Furnequip + Hhmaint + Communication + Computer + Transport + Reading + Housing + Restaurant + Health + Recreation + Education + Personalcare + Personaleffects + Feesandgifts + Finance + Otherexp
	
	tempvar cpi_excl
	gen `cpi_excl' = TOTAL_EXP_excl/`temp'*100
	
	foreach category in inc de unmatcheddebts in out {
		ds *_`category'
		
		tokenize "`r(varlist)'"
		while "`1'"~="" {
			forvalues year = 1995(5)2010 {
				replace `1' = `1'/`cpi_excl'*100 if year==`year'
			}
			macro shift
		}	
	}
	
	drop `temp'
	
	egen `temp' = rowtotal(Work_inc-Allother_inc)
	replace TOTAL_INC = `temp'
	drop `temp'
	
	egen `temp' = rowtotal(*_de)
	replace Debts = `temp'
	drop `temp'
	local chosen = "ex"
}
else if "`chosen'"=="I" {
	gen `temp' = Food + Nonalcoholic + Alcohol + Tobacco + Clothing + Fuel + Furnequip + Hhmaint + Communication + Computer + Transport + Reading + Housing + Restaurant + Health + Recreation + Education + Personalcare + Personaleffects + Feesandgifts + Finance + Otherexp + Unmatchedexp
	
	tempvar cpi_incl
	gen `cpi_incl' = TOTAL_EXP_incl/`temp'*100
	
	foreach category in inc de unmatcheddebts in out {
		ds *_`category'
		
		tokenize "`r(varlist)'"
		while "`1'"~="" {
			forvalues year = 1995(5)2010 {
				replace `1' = `1'/`cpi_incl'*100 if year==`year'
			}
			macro shift
		}	
	}
	
	drop `temp'
	
	egen `temp' = rowtotal(Work_inc-Allother_inc)
	replace TOTAL_INC = `temp'
	drop `temp'
	
	egen `temp' = rowtotal(*_de)
	replace Debts = `temp'
	drop `temp'
	local chosen = "in"
}	

replace TOTAL_EXP_excl = Food + Nonalcoholic + Alcohol + Tobacco + Clothing + Fuel + Furnequip + Hhmaint + Communication + Computer + Transport + Reading + Housing + Restaurant + Health + Recreation + Education + Personalcare + Personaleffects + Feesandgifts + Finance + Otherexp
replace TOTAL_EXP_incl = TOTAL_EXP_excl + Unmatchedexp

note replace _dta in 1: PIES: 1995-2010, real values (multiple deflators), income deflated using total expenditure `chosen'cluding unmatched expenditures.

save "$DATADIR/PIES_real2.dta", replace
